==> ae_kivy_relief_canvas-0.1.6.tar.gz: ae_kivy_relief_canvas-0.1.6/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# kivy_relief_canvas portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_relief_canvas/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_relief_canvas)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_relief_canvas/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/coverage/ae_kivy_relief_canvas_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_relief_canvas/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_relief_canvas/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_relief_canvas)](
    https://libraries.io/pypi/ae-kivy-relief-canvas)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/#files)


## installation


Execute the following command for to use the ae.kivy_relief_canvas module in your
application. It will install ae.kivy_relief_canvas into your python (virtual) environment:
 
```shell script
pip install ae-kivy-relief-canvas
```

If you instead want to contribute to this portion then first fork
[the ae_kivy_relief_canvas repository at GitLab](https://gitlab.com/ae-group/ae_kivy_relief_canvas "ae.kivy_relief_canvas code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_relief_canvas):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_relief_canvas.html#module-ae.kivy_relief_canvas
"ae_kivy_relief_canvas documentation").

<!-- Common files version 0.1.62 deployed version 0.1.0 (with 0.1.62)
     to https://gitlab.com/ae-group as ae_kivy_relief_canvas module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-relief-canvas as namespace portion ae-kivy-relief-canvas.
-->

==> ae_kivy_relief_canvas-0.2.7.tar.gz: ae_kivy_relief_canvas-0.2.7/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# kivy_relief_canvas portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_relief_canvas/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_relief_canvas)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_relief_canvas/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/coverage/ae_kivy_relief_canvas_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_relief_canvas/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_relief_canvas/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_relief_canvas/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_relief_canvas)](
    https://libraries.io/pypi/ae-kivy-relief-canvas)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_relief_canvas)](
    https://pypi.org/project/ae-kivy-relief-canvas/#files)


## installation


execute the following command to use the ae.kivy_relief_canvas module in your
application. it will install ae.kivy_relief_canvas into your python (virtual) environment:
 
```shell script
pip install ae-kivy-relief-canvas
```

if you instead want to contribute to this portion then first fork
[the ae_kivy_relief_canvas repository at GitLab](https://gitlab.com/ae-group/ae_kivy_relief_canvas "ae.kivy_relief_canvas code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_relief_canvas):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_relief_canvas.html#module-ae.kivy_relief_canvas
"ae_kivy_relief_canvas documentation").

<!-- common files version 0.2.77 deployed version 0.2.7 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_kivy_relief_canvas module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-relief-canvas as namespace portion ae-kivy-relief-canvas.
-->
